@@ -3,6 +3,6 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from vrt_lss_routing.api.check_api import CheckApi
 from vrt_lss_routing.api.matrix_api import MatrixApi
 from vrt_lss_routing.api.route_api import RouteApi
+from vrt_lss_routing.api.system_api import SystemApi
